Module db

Module db 

Database service layer for KoReader synchronization.

This module defines the KorrosyncService trait which provides an abstract interface for managing persistent storage of user authentication and reading progress synchronization.

Implementations

Currently available implementations:

Re-exports

pub use self::redb::KorrosyncServiceRedb;

Modules

redb
Redb-based implementation of KOReader synchronization service.

Traits

KorrosyncService
Trait defining the core database operations for KoReader synchronization.